@@ -260,5 +260,5 @@ class Assert:
             return center_pos_dpi
         except RuntimeError as e:
             print("图片点击运行错误：", e)
-        # finally:
-        #     Path(shot_pic).unlink(missing_ok=True)
+        finally:
+            Path(shot_pic).unlink(missing_ok=True)
